import pytest
from django_dynamic_fixture import G

from silver.models import Transaction, Proforma, Invoice, Customer
from silver import payment_processors
from silver_payu.models import PayUPaymentMethod


@pytest.fixture
def customer():
    return G(Customer, currency='RON', address_1='9', address_2='9',
             sales_tax_number=0)


@pytest.fixture
def payment_processor():
    return payment_processors.get_instance('payu_manual')


@pytest.fixture
def payment_processor_triggered():
    return payment_processors.get_instance('payu_triggered')


@pytest.fixture
def payment_method(customer, payment_processor):
    return G(PayUPaymentMethod, customer=customer,
             payment_processor=payment_processor.name)


@pytest.fixture
def proforma(customer):
    return G(Proforma, state=Invoice.STATES.ISSUED, customer=customer,
             transaction_currency='RON')


@pytest.fixture
def invoice(customer, proforma):
    return G(Invoice, related_document=proforma, state=Invoice.STATES.ISSUED,
             customer=customer, transaction_currency='RON')


@pytest.fixture
def transaction(customer, payment_processor, payment_method, proforma, invoice):
    return G(Transaction, invoice=invoice, proforma=proforma, currency='RON',
             amount=invoice.total, payment_method=payment_method)


@pytest.fixture
def transaction_triggered(customer, payment_processor_triggered,
                          payment_method, proforma, invoice):
    return G(Transaction, invoice=invoice, proforma=proforma, currency='RON',
             amount=invoice.total, payment_method=payment_method)



import pytest
from mock import patch

from silver_payu.forms import PayUTransactionFormBase

from .fixtures import (customer, transaction, payment_method,
                       payment_processor, proforma, invoice)


@pytest.mark.django_db
@patch('silver_payu.forms.datetime')
def test_payu_transaction_form_build_body(mocked_datetime, transaction,
                                          payment_method):
    mocked_datetime.now.return_value.strftime.return_value = 'order_date'

    with patch('silver.utils.payments._get_jwt_token') as mocked_token:
        mocked_token.return_value = 'token'

        form = PayUTransactionFormBase(payment_method, transaction, {})

        assert form._build_form_body(transaction, None) == {
            'AUTOMODE': '1',
            'BACK_REF': '/pay/token/complete',
            'CURRENCY': 'RON',
            'ORDER': [{'PCODE': '%s-%s' % (transaction.document.series,
                                           transaction.document.number),
                       'PNAME': 'Payment for %s %s-%s' % (transaction.document.kind,
                                                          transaction.document.series,
                                                          transaction.document.number),
                       'PRICE': str(transaction.amount),
                       'PRICE_TYPE': 'GROSS',
                       'VAT': str(transaction.document.sales_tax_percent)}],
            'ORDER_DATE': 'order_date',
            'ORDER_REF': '%s' % transaction.uuid,
            'PAY_METHOD': 'CCVISAMC',
            'PRICES_CURRENCY': 'RON'
        }



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('silver', '0032_auto_20170201_1342'),
    ]

    operations = [
        migrations.CreateModel(
            name='PayUPaymentMethod',
            fields=[
            ],
            options={
                'proxy': True,
            },
            bases=('silver.paymentmethod',),
        ),
    ]
